(self.webpackChunk_mattermost_webapp=self.webpackChunk_mattermost_webapp||[]).push([[821],{76821:(e,t,a)=>{"use strict";a.r(t),a.d(t,{default:()=>u});var n=a(45697),s=a.n(n),i=(a(33948),a(4002)),r=a.n(i),l=a(67294),c=a(47470);function o(e,t,a){return t in e?Object.defineProperty(e,t,{value:a,enumerable:!0,configurable:!0,writable:!0}):e[t]=a,e}class u extends l.PureComponent{constructor(...e){super(...e),o(this,"handleClick",((e,t)=>{t.preventDefault(),this.props.updateTab(e.name),r()(t.target).closest(".settings-modal").addClass("display--content")}))}componentDidMount(){c.vU()&&r()(".settings-modal .settings-table .nav").addClass("position--top")}render(){const e=this.props.tabs.map((e=>{const t="".concat(e.name,"_li");let a="";return this.props.activeTab===e.name&&(a="active"),l.createElement("li",{id:"".concat(e.name,"Li"),key:t,className:a},l.createElement("button",{id:"".concat(e.name,"Button"),className:"cursor--pointer style--none",onClick:this.handleClick.bind(null,e),"aria-label":e.uiName.toLowerCase()},l.createElement("i",{className:e.icon,title:e.iconTitle}),e.uiName))}));return l.createElement("div",null,l.createElement("ul",{id:"tabList",className:"nav nav-pills nav-stacked"},e))}}o(u,"propTypes",{activeTab:s().string,tabs:s().arrayOf(s().shape({icon:s().string.isRequired,iconTitle:s().string.isRequired,name:s().string.isRequired,uiName:s().string.isRequired})).isRequired,updateTab:s().func.isRequired})}}]);
//# sourceMappingURL=821.7886936d86b20acb303c.js.map