.Header{display:flex;align-items:center;justify-content:space-between;padding:0 16px}.Header h1,.Header h2,.Header h3,.Header h4,.Header h5,.Header h6{margin:0;line-height:1}.Header h2{color:rgba(var(--center-channel-color-rgb), 1);font-size:16px;font-weight:600}.Header>div p{margin:6px 0 0;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:12px;font-weight:400;line-height:16px}.Header>.spacer{flex:1}
.ThreadItem{--border: 1px solid rgba(var(--center-channel-color-rgb), 0.08);position:relative;padding:18px 18px 18px 28px;cursor:pointer;text-align:left}.ThreadItem .alt-visible{visibility:hidden}.ThreadItem:hover,.ThreadItem:focus,.ThreadItem:focus-within{background:rgba(var(--center-channel-color-rgb), 0.04)}.ThreadItem:hover .alt-visible,.ThreadItem:focus .alt-visible,.ThreadItem:focus-within .alt-visible{visibility:unset}.ThreadItem:hover .alt-hidden,.ThreadItem:focus .alt-hidden,.ThreadItem:focus-within .alt-hidden{visibility:hidden}.ThreadItem.is-selected{background:rgba(var(--button-bg-rgb), 0.04)}.ThreadItem.is-selected:hover,.ThreadItem.is-selected:focus{background:rgba(var(--button-bg-rgb), 0.08)}.ThreadItem .activity{display:flex;align-items:center;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:12px;font-weight:600;line-height:15px}.ThreadItem.has-unreads .activity{color:rgba(var(--sidebar-text-active-border-rgb), 1)}.ThreadItem .dot-unreads{display:inline-block;width:8px;height:8px;margin:0 8px;background:rgba(var(--sidebar-text-active-border-rgb), 1);border-radius:50%;text-align:center}.ThreadItem .dot-mentions{display:inline-block;width:16px;height:16px;background:rgba(var(--mention-color-rgb), 1);border-radius:50%;color:rgba(var(--center-channel-bg-rgb), 1);font-size:10px;font-weight:700;line-height:16px;text-align:center}.ThreadItem .dot-mentions.over{font-size:8px}.ThreadItem .indicator{position:absolute;left:-24px;display:grid;width:24px;height:20px;place-content:center}.ThreadItem h1{position:relative;display:grid;margin:0 0 6px;font-size:14px;font-weight:600;grid-template-columns:min-content 1fr min-content;line-height:20px;white-space:nowrap}.ThreadItem .Badge{min-width:0;max-width:30rem;margin:0 10px}.ThreadItem .Badge__box{overflow:hidden;padding:0 4px;background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 1);font-size:10px;font-weight:600;line-height:16px;text-overflow:ellipsis;text-transform:uppercase}.ThreadItem .Badge__box:hover,.ThreadItem .Badge__box:focus{background:rgba(var(--center-channel-color-rgb), 0.16);cursor:pointer}.ThreadItem div.preview{height:40px;margin:0 0 10px;color:rgba(var(--center-channel-color-rgb), 1);display:-webkit-box;overflow:hidden;-webkit-box-orient:vertical;-webkit-line-clamp:2;max-height:40px}.ThreadItem time{color:rgba(var(--center-channel-color-rgb), 0.64);font-size:12px;font-weight:normal;line-height:20px}.ThreadItem .menu-anchor{position:absolute;top:12px;right:14px}.ThreadItem .menu-anchor .Button{width:28px;height:28px;padding:0;font-size:18px}.ThreadItem .MenuWrapper .dropdown-menu{min-width:250px}.ThreadItem .Avatars{margin-right:10px}
.ThreadMenu .MenuItem__help-text{margin:0}
.ThreadList{display:grid;overflow:hidden;grid-template-areas:"header" "list";grid-template-rows:56px 1fr}.ThreadList .Header{padding-right:12px;padding-left:14px;border-bottom:var(--border);color:rgba(var(--center-channel-color-rgb), 0.56);grid-area:header}.ThreadList .Header .Button+.Button{margin-left:4px}.ThreadList .threads{grid-area:list}.ThreadList .threads .no-results__wrapper{position:relative;top:-28px}.ThreadList .ThreadItem{border-bottom:var(--border)}
.ThreadPane{display:grid;overflow:hidden;grid-template-areas:"header" "pane";grid-template-rows:56px 1fr}.ThreadPane .Header{display:flex;height:56px;align-items:center;justify-content:space-between;padding:12px 16px;border-bottom:var(--border);grid-area:header;--button-separator-height: 24px}.ThreadPane .Header .left{display:flex}.ThreadPane .Header .back{display:none;flex-shrink:0}.ThreadPane .Header .FollowButton,.ThreadPane .Header h3 .Button{height:24px;padding:4px 8px;font-size:12px;line-height:16px}.ThreadPane .Header h3{display:inline-grid;align-items:center;margin:0 10px 0 0;color:rgba(var(--center-channel-color-rgb), 1);grid-template-columns:max-content 1fr}.ThreadPane .Header h3>span{padding-right:8px;padding-left:4px;font-size:16px;font-weight:600;line-height:32px;vertical-align:top}.ThreadPane .Header h3 .Button{color:rgba(var(--center-channel-color-rgb), 0.56);font-weight:400}.ThreadPane .Header .MenuWrapper{margin-left:4px}.ThreadPane .Header .MenuWrapper .dropdown-menu{min-width:250px}.ThreadPane .ThreadViewer{overflow:hidden;grid-area:pane}.ThreadPane .ThreadViewer .post-right__scroll{padding-top:0}
.GlobalThreads___title span{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.GlobalThreads{--border: 1px solid rgba(var(--center-channel-color-rgb), 0.16);--list: minmax(min-content, 300px);--pane: minmax(min-content, auto);display:grid;overflow:hidden;grid-template-areas:"header header" "list pane";grid-template-columns:var(--list) var(--pane);grid-template-rows:63px 1fr}.GlobalThreads .GlobalThreads___header{border-bottom:var(--border);grid-area:header}.GlobalThreads .channel-header__icon,.GlobalThreads .search__form{margin-top:1px}.GlobalThreads .ThreadList{border-right:var(--border);grid-area:list}.GlobalThreads .ThreadPane,.GlobalThreads .ThreadList+.no-results__holder{grid-area:pane}.GlobalThreads>.no-results__holder{grid-area:list/list/pane/pane}@media screen and (max-width: 1020px){.GlobalThreads>.no-results__holder{grid-area:main}}.GlobalThreads .no-results__wrapper svg{margin-bottom:20px}.GlobalThreads .no-results__subtitle{max-width:378px}.GlobalThreads .ThreadPane{overflow:hidden}@media screen and (max-width: 1020px){.GlobalThreads{grid-template-areas:"header header" "main main"}.GlobalThreads:not(.thread-selected) .ThreadList{grid-area:main}.GlobalThreads:not(.thread-selected) .ThreadPane,.GlobalThreads:not(.thread-selected) .ThreadList+.no-results__holder{display:none}.GlobalThreads.thread-selected .ThreadList{display:none}.GlobalThreads.thread-selected .ThreadPane{grid-area:main}.GlobalThreads.thread-selected .ThreadPane .Header{padding-left:5px}.GlobalThreads.thread-selected .ThreadPane .back{display:unset}}@media screen and (max-width: 768px){.GlobalThreads{grid-template-rows:0 1fr}.GlobalThreads>.Header{display:none}.GlobalThreads .Header{border-top:var(--border)}}@media screen and (min-width: 1021px){.GlobalThreads{--list: minmax(min-content, 350px)}}@media screen and (min-width: 1267px){.GlobalThreads{--list: minmax(min-content, 400px)}}@media screen and (min-width: 1680px){.GlobalThreads{--list: minmax(min-content, 500px)}}.sidebar--right.move--left~.inner-wrap{--rhs-width: 0}@media screen and (min-width: 1267px){.sidebar--right.move--left~.inner-wrap{--rhs-width: 400px}}@media screen and (min-width: 1680px){.sidebar--right.move--left~.inner-wrap{--rhs-width: 500px}}.sidebar--right.move--left~.inner-wrap #app-content.GlobalThreads .ThreadList+.no-results__holder,.sidebar--right.move--left~.inner-wrap #app-content.GlobalThreads .ThreadPane{padding-right:var(--rhs-width)}

/*# sourceMappingURL=511.b84b720b7cbf7ae7422c.css.map*/