{{define "over_user_limit_support_body"}}
<html>
<body>
  <p>Installation with ID: {{ .Props.InstallationID }} has been in arrears for over 30 days, and is scheduled for suspension on {{ .Props.SuspensionDate }}</p><br>
  <p>Site URL: {{ .Props.SiteURL }}</p><br>
  <p>Subscription ID: {{ .Props.SubscriptionID }}</p><br>
  <p>Number of registered users: {{ .Props.UserCount }}</p>
</body>
</html>
{{end}}
